==> kde-l10n-gl-4.4.3-noarch-1.tgz: install/doinst.sh <==
( cd usr/share/doc/HTML/gl/kalzium ; rm -rf common )
( cd usr/share/doc/HTML/gl/kalzium ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kgamma ; rm -rf common )
( cd usr/share/doc/HTML/gl/kgamma ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kmail ; rm -rf common )
( cd usr/share/doc/HTML/gl/kmail ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/step ; rm -rf common )
( cd usr/share/doc/HTML/gl/step ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/gl/gwenview ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/gl/kbruch ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kgeography ; rm -rf common )
( cd usr/share/doc/HTML/gl/kgeography ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kaddressbook ; rm -rf common )
( cd usr/share/doc/HTML/gl/kaddressbook ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kruler ; rm -rf common )
( cd usr/share/doc/HTML/gl/kruler ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/blinken ; rm -rf common )
( cd usr/share/doc/HTML/gl/blinken ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/gl/kolourpaint ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kturtle ; rm -rf common )
( cd usr/share/doc/HTML/gl/kturtle ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kstars ; rm -rf common )
( cd usr/share/doc/HTML/gl/kstars ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/plasma-desktop ; rm -rf common )
( cd usr/share/doc/HTML/gl/plasma-desktop ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/umbrello ; rm -rf common )
( cd usr/share/doc/HTML/gl/umbrello ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kanagram ; rm -rf common )
( cd usr/share/doc/HTML/gl/kanagram ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/sonnet ; rm -rf common )
( cd usr/share/doc/HTML/gl/sonnet ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/lokalize ; rm -rf common )
( cd usr/share/doc/HTML/gl/lokalize ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/okular ; rm -rf common )
( cd usr/share/doc/HTML/gl/okular ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kinfocenter/usb ; rm -rf common )
( cd usr/share/doc/HTML/gl/kinfocenter/usb ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/gl/kwordquiz ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcontrol/kamera ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcontrol/kamera ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/klettres ; rm -rf common )
( cd usr/share/doc/HTML/gl/klettres ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/akregator ; rm -rf common )
( cd usr/share/doc/HTML/gl/akregator ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/sftp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/sftp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/tar ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/tar ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/cgi ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/cgi ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/fish ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/fish ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/data ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/data ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/floppy ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/floppy ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/man ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/man ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/finger ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/finger ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/ftp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/ftp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/nfs ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/nfs ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/telnet ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/telnet ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/rlogin ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/thumbnail ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/smb ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/smb ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/mailto ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/mailto ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/info ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/info ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/file ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/file ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/gl/ksnapshot ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcachegrind ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcachegrind ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/gl/ktouch ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/gl/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/gl//common common )

==> kde-l10n-gl-4.5.5-noarch-1.tgz: install/doinst.sh <==
( cd usr/share/doc/HTML/gl/umbrello ; rm -rf common )
( cd usr/share/doc/HTML/gl/umbrello ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcontrol/kamera ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcontrol/kamera ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/gl/kwordquiz ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/gl/ktouch ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/telnet ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/telnet ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/sftp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/sftp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/mailto ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/mailto ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/nfs ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/nfs ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/finger ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/finger ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/file ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/file ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/smb ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/smb ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/nntp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/nntp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/thumbnail ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/floppy ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/floppy ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/ftp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/ftp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/data ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/data ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/tar ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/tar ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/cgi ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/cgi ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/rlogin ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/fish ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/fish ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/info ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/info ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/man ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/man ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/ldap ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/ldap ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kioslave/smtp ; rm -rf common )
( cd usr/share/doc/HTML/gl/kioslave/smtp ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/okular ; rm -rf common )
( cd usr/share/doc/HTML/gl/okular ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/gl/kbruch ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kstars ; rm -rf common )
( cd usr/share/doc/HTML/gl/kstars ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kanagram ; rm -rf common )
( cd usr/share/doc/HTML/gl/kanagram ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/blinken ; rm -rf common )
( cd usr/share/doc/HTML/gl/blinken ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/gl/gwenview ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/gl/ksnapshot ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kruler ; rm -rf common )
( cd usr/share/doc/HTML/gl/kruler ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/gl/kolourpaint ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kalzium ; rm -rf common )
( cd usr/share/doc/HTML/gl/kalzium ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/klettres ; rm -rf common )
( cd usr/share/doc/HTML/gl/klettres ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/lokalize ; rm -rf common )
( cd usr/share/doc/HTML/gl/lokalize ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kgeography ; rm -rf common )
( cd usr/share/doc/HTML/gl/kgeography ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/step ; rm -rf common )
( cd usr/share/doc/HTML/gl/step ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/plasma-desktop ; rm -rf common )
( cd usr/share/doc/HTML/gl/plasma-desktop ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/sonnet ; rm -rf common )
( cd usr/share/doc/HTML/gl/sonnet ; ln -sf /usr/share/doc/HTML/gl//common common )
( cd usr/share/doc/HTML/gl/kcachegrind ; rm -rf common )
( cd usr/share/doc/HTML/gl/kcachegrind ; ln -sf /usr/share/doc/HTML/gl//common common )
